"""
    Title: setting.py
    Author: Kushagra A.
    Language: Python
    Date Created: 05-09-2021
    Date Modified: 22-09-2021
    Description:
        ###############################################################
        ## Create a environment variable in dictionary   ## 
         ###############################################################
 """


info = {
    "HOST" : "3.6.156.104:5004",
    "PUSH_COMMIT_URL" : "http://3.6.156.104:5004/push_commit",
    "FETCH_LOG_URL" : "http://3.6.156.104:5004/fetch_log",
    "GET_SHA_URL" : "http://3.6.156.104:5004/get_sha",
    "key" : "HB2xRCZSyKYMcTS9rm",
    "secret_key" : "pQA5FMShe6deqr2b8Eq3GfDBmhEnn77C",
    "version": "1.04"
}

